Analyse dataset from minimal example scenario with linear regression
analyse_minimal_example_lm.RdAnalyse dataset from minimal example scenario with linear regression
Value
an analyse function that returns a list with the elements
pthe p-value of the F-testcoefthe point estimateci_lowerthe lower CI limitci_upperthe upper CI limit
Examples
Design <- assumptions_minimal_example() |>
true_summary_statistics_minimal_example()
condition <- Design[1, ]
dat <- generate_minimal_example(condition)
my_analyse_lm <- analyse_minimal_example_lm(ci_level=0.9)
my_analyse_lm(condition, dat)
#> $p
#> [1] 0.0005817177
#>
#> $coef
#> group
#> 0.7384848
#>
#> $ci_lower
#> [1] 0.3936358
#>
#> $ci_upper
#> [1] 1.083334
#>