Generate Grid of Parameter Values
params_scenarios_grid.RdGenerate Grid of Parameter Values
Details
The first value of each argument is taken to be the reference value. In addition to the reference scenario the output contains one line per additional value in each of the input arguments In each of those lines only one parameter is varied. Each line differs from the first line in exactly one column.
List columns can be used as they can be used in tibbles.